@@ -335,7 +335,7 @@ class soupManager:
         - attribute_values: Dictionary where each key is an attribute and the value is a list of unique values for that attribute.
         """
         attribute_values = {}
-        tags_list = tags_list or self.all_tags_and_attributes
+        tags_list = tags_list or self.get_all_tags_and_attribute_names()
         # Get all tags matching tags_list criteria
         for tag_name in tags_list:
             for tag in self.soup.find_all(tag_name):
